@@ -1,13 +1,20 @@
 /* Copyright (c) 2000, 2015, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
@@ -1279,8 +1286,8 @@ bool Global_backup_lock::acquire(THD *thd)
 
   DBUG_ENTER("Global_backup_lock::acquire");
 
-  DBUG_ASSERT(m_lock == NULL &&
-              !thd->mdl_context.is_lock_owner(m_namespace, "", "",
+  DBUG_ASSERT(m_lock == NULL);
+  DBUG_ASSERT(!thd->mdl_context.is_lock_owner(m_namespace, "", "",
                                               MDL_SHARED));
 
   mdl_request.init(m_namespace, "", "", MDL_SHARED, MDL_EXPLICIT);
@@ -1304,8 +1311,8 @@ void Global_backup_lock::release(THD *thd)
 {
   DBUG_ENTER("Global_backup_lock::release");
 
-  DBUG_ASSERT(m_lock != NULL &&
-              thd->mdl_context.is_lock_owner(m_namespace, "", "",
+  DBUG_ASSERT(m_lock != NULL);
+  DBUG_ASSERT(thd->mdl_context.is_lock_owner(m_namespace, "", "",
                                              MDL_SHARED));
 
   thd->mdl_context.release_lock(m_lock);
@@ -1406,8 +1413,8 @@ void Global_backup_lock::release_protection(THD *thd)
 {
   DBUG_ENTER("Global_backup_lock::release_protection");
 
-  DBUG_ASSERT(m_prot_lock != NULL &&
-              thd->mdl_context.is_lock_owner(m_namespace, "", "",
+  DBUG_ASSERT(m_prot_lock != NULL);
+  DBUG_ASSERT(thd->mdl_context.is_lock_owner(m_namespace, "", "",
                                              MDL_INTENTION_EXCLUSIVE));
 
   thd->mdl_context.release_lock(m_prot_lock);
