@@ -1,13 +1,20 @@
-/* Copyright (c) 2010, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2010, 2019, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
@@ -862,7 +869,7 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
   bool time_for_hb_event= false;
   int error= 0;
   const char *errmsg = "Unknown error";
-  char error_text[MAX_SLAVE_ERRMSG]; // to be send to slave via my_message()
+  char error_text[MAX_SLAVE_ERRMSG]= {0}; // to be send to slave via my_message()
   NET* net = &thd->net;
   mysql_mutex_t *log_lock;
   mysql_cond_t *log_cond;
@@ -1007,7 +1014,7 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
       */
       if (!gtid_state->get_lost_gtids()->is_subset(slave_gtid_executed))
       {
-        errmsg= ER(ER_MASTER_HAS_PURGED_REQUIRED_GTIDS);
+        mysql_bin_log.report_missing_purged_gtids(slave_gtid_executed, &errmsg);
         my_errno= ER_MASTER_FATAL_ERROR_READING_BINLOG;
         global_sid_lock->unlock();
         GOTO_ERR;
