@@ -3,13 +3,20 @@
 /* Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -350,6 +357,8 @@ extern SHOW_COMP_OPTION have_statement_timeout;
 extern SHOW_COMP_OPTION have_backup_locks;
 extern SHOW_COMP_OPTION have_backup_safe_binlog_info;
 extern SHOW_COMP_OPTION have_snapshot_cloning;
+extern SHOW_COMP_OPTION have_tlsv1_2;
+extern SHOW_COMP_OPTION have_elliptic_curve_crypto;
 
 /*
   Prototypes for helper functions
@@ -358,7 +367,10 @@ extern SHOW_COMP_OPTION have_snapshot_cloning;
 SHOW_VAR* enumerate_sys_vars(THD *thd, bool sorted, enum enum_var_type type);
 
 sys_var *find_sys_var(THD *thd, const char *str, uint length=0);
-int sql_set_variables(THD *thd, List<set_var_base> *var_list);
+
+MY_ATTRIBUTE((warn_unused_result))
+int sql_set_variables(THD *thd, List<set_var_base> *var_list,
+                      bool free_joins = true);
 
 bool fix_delay_key_write(sys_var *self, THD *thd, enum_var_type type);
 
@@ -379,5 +391,9 @@ int sys_var_init();
 int sys_var_add_options(std::vector<my_option> *long_options, int parse_flags);
 void sys_var_end(void);
 
+extern void init_log_slow_verbosity();
+extern void init_slow_query_log_use_global_control();
+extern void init_log_slow_sp_statements();
+
 #endif
 
