@@ -21,6 +21,7 @@
 #include <sql_acl.h>
 #include <sql_reload.h>
 #include <sql_parse.h>
+#include <mysql_version.h>
 #include "wsrep_priv.h"
 #include "wsrep_utils.h"
 #include "wsrep_xid.h"
@@ -38,6 +39,7 @@ extern const char wsrep_defaults_group_suffix[];
 #define WSREP_SST_OPT_CONF_SUFFIX "--defaults-group-suffix"
 #define WSREP_SST_OPT_PARENT   "--parent"
 #define WSREP_SST_OPT_BINLOG   "--binlog"
+#define WSREP_SST_OPT_VERSION  "--mysqld-version"
 
 // mysqldump-specific options
 #define WSREP_SST_OPT_USER     "--user"
@@ -332,7 +334,10 @@ void wsrep_sst_continue ()
   if (sst_needed)
   {
     WSREP_INFO("Signalling provider to continue.");
-    wsrep_sst_received (wsrep, local_uuid, local_seqno, NULL, 0);
+    // local_uuid and local_seqno are global variables and are volatile
+    wsrep_uuid_t  const sst_uuid  = local_uuid;
+    wsrep_seqno_t const sst_seqno = local_seqno;
+    wsrep_sst_received (wsrep, sst_uuid, sst_seqno, NULL, 0);
   }
 }
 
@@ -407,8 +412,7 @@ static int generate_binlog_opt_val(char** ret)
   if (opt_bin_log && gtid_mode > 0)
   {
     assert(opt_bin_logname);
-    *ret= strcmp(opt_bin_logname, "0") ?
-        my_strdup(opt_bin_logname, MYF(0)) : my_strdup("", MYF(0));
+    *ret= my_strdup(opt_bin_logname, MYF(0));
   }
   else
   {
@@ -426,18 +430,29 @@ static wsp::process * sst_process= static_cast<wsp::process*>(NULL);
 
 static bool sst_cancelled= false;
 
-void wsrep_sst_cancel ()
+void wsrep_sst_cancel (bool call_wsrep_cb)
 {
   if (mysql_mutex_lock (&LOCK_wsrep_sst)) abort();
   if (!sst_cancelled)
   {
     sst_cancelled=true;
+    /*
+      When we launched the SST process, then we need
+      to terminate it before exit from the parent (server)
+      process:
+    */
     if (sst_process)
     {
       sst_process->terminate();
       sst_process = NULL;
     }
-    if (sst_awaiting_callback)
+    /*
+      If this is a normal shutdown, then we need to notify
+      the wsrep provider about completion of the SST, to
+      prevent infinite waitng in the wsrep provider after
+      the SST process was canceled:
+    */
+    if (call_wsrep_cb && sst_awaiting_callback)
     {
       WSREP_INFO("Signalling cancellation of the SST request.");
       wsrep_gtid_t const state_id = {
@@ -451,6 +466,23 @@ void wsrep_sst_cancel ()
   mysql_mutex_unlock (&LOCK_wsrep_sst);
 }
 
+/*
+  Handling of fatal signals: SIGABRT, SIGTERM, etc.
+*/
+extern "C" void wsrep_handle_fatal_signal (int sig)
+{
+  wsrep_sst_cancel(false);
+}
+
+/*
+  This callback is invoked in the case of abnormal
+  termination of the wsrep provider:
+*/
+void wsrep_abort_cb (void)
+{
+  wsrep_sst_cancel(false);
+}
+
 static void* sst_joiner_thread (void* a)
 {
   sst_thread_arg* arg= (sst_thread_arg*) a;
@@ -623,11 +655,13 @@ static ssize_t sst_prepare_other (const char*  method,
                  WSREP_SST_OPT_DATA" '%s' "
                  WSREP_SST_OPT_CONF" '%s' "
                  WSREP_SST_OPT_CONF_SUFFIX" '%s' "
-                 WSREP_SST_OPT_PARENT" '%d'"
+                 WSREP_SST_OPT_PARENT" '%d' "
+                 WSREP_SST_OPT_VERSION" '%s' "
                  " %s '%s' ",
                  method, addr_in, mysql_real_data_home,
                  wsrep_defaults_file, wsrep_defaults_group_suffix,
-                 (int)getpid(), binlog_opt, binlog_opt_val);
+                 (int)getpid(), MYSQL_SERVER_VERSION MYSQL_SERVER_SUFFIX_DEF,
+                 binlog_opt, binlog_opt_val);
   my_free(binlog_opt_val);
 
   if (ret < 0 || ret >= cmd_len)
@@ -738,18 +772,19 @@ ssize_t wsrep_sst_prepare (void** msg)
 
   // Figure out SST address. Common for all SST methods
   if (wsrep_sst_receive_address &&
-    strcmp (wsrep_sst_receive_address, WSREP_SST_ADDRESS_AUTO))
+      strcmp (wsrep_sst_receive_address, WSREP_SST_ADDRESS_AUTO))
   {
     addr_in= wsrep_sst_receive_address;
   }
   else if (wsrep_node_address && strlen(wsrep_node_address))
   {
-    const char* const colon= strchr (wsrep_node_address, ':');
-    if (colon)
+    size_t const addr_len= strlen(wsrep_node_address);
+    size_t const host_len= wsrep_host_len(wsrep_node_address, addr_len);
+
+    if (host_len < addr_len)
     {
-      ptrdiff_t const len= colon - wsrep_node_address;
-      strncpy (ip_buf, wsrep_node_address, len);
-      ip_buf[len]= '\0';
+      strncpy (ip_buf, wsrep_node_address, host_len);
+      ip_buf[host_len]= '\0';
       addr_in= ip_buf;
     }
     else
@@ -901,25 +936,6 @@ static int sst_donate_mysqldump (const char*         addr,
                                  bool                bypass,
                                  char**              env) // carries auth info
 {
-  size_t host_len;
-  const char* port = strchr (addr, ':');
-
-  if (port)
-  {
-    port += 1;
-    host_len = port - addr;
-  }
-  else
-  {
-    port = "";
-    host_len = strlen (addr) + 1;
-  }
-
-  char *host= static_cast<char *>(alloca(host_len));
-
-  strncpy (host, addr, host_len - 1);
-  host[host_len - 1] = '\0';
-
   int const cmd_len= 4096;
   wsp::string  cmd_str(cmd_len);
 
@@ -934,16 +950,18 @@ static int sst_donate_mysqldump (const char*         addr,
 
   int ret= snprintf (cmd_str(), cmd_len,
                      "wsrep_sst_mysqldump "
-                     WSREP_SST_OPT_HOST" '%s' "
-                     WSREP_SST_OPT_PORT" '%s' "
+                     WSREP_SST_OPT_ADDR" '%s' "
                      WSREP_SST_OPT_LPORT" '%u' "
                      WSREP_SST_OPT_SOCKET" '%s' "
                      WSREP_SST_OPT_CONF" '%s' "
-                     WSREP_SST_OPT_GTID" '%s:%lld'"
+                     WSREP_SST_OPT_GTID" '%s:%lld' "
+                     WSREP_SST_OPT_VERSION" '%s' "
                      "%s",
-                     host, port, mysqld_port, mysqld_unix_port,
+                     addr, mysqld_port, mysqld_unix_port,
                      wsrep_defaults_file, uuid_str,
-                     (long long)seqno, bypass ? " "WSREP_SST_OPT_BYPASS : "");
+                     (long long)seqno,
+                     MYSQL_SERVER_VERSION MYSQL_SERVER_SUFFIX_DEF,
+                     bypass ? " " WSREP_SST_OPT_BYPASS : "");
 
   if (ret < 0 || ret >= cmd_len)
   {
@@ -959,7 +977,6 @@ static int sst_donate_mysqldump (const char*         addr,
 
   wsrep->sst_sent (wsrep, &state_id, ret);
 
-
   return ret;
 }
 
@@ -976,7 +993,7 @@ static int run_sql_command(THD *thd, const char *query)
     return -1;
   }
 
-  mysql_parse(thd, thd->query(), thd->query_length(), &ps);
+  mysql_parse(thd, thd->query(), thd->query_length(), &ps, false);
   if (thd->is_error())
   {
     int const err= thd->get_stmt_da()->sql_errno();
@@ -999,7 +1016,7 @@ static int sst_flush_tables(THD* thd)
   if (run_sql_command(thd, "FLUSH TABLES WITH READ LOCK"))
   {
     WSREP_ERROR("Failed to flush and lock tables");
-    err = -1;
+    err = ECANCELED;
   }
   else
   {
@@ -1223,14 +1240,16 @@ static int sst_donate_other (const char*   method,
                  WSREP_SST_OPT_DATA" '%s' "
                  WSREP_SST_OPT_CONF" '%s' "
                  WSREP_SST_OPT_CONF_SUFFIX" '%s' "
+                 WSREP_SST_OPT_VERSION" '%s' "
                  " %s '%s' "
-                 WSREP_SST_OPT_GTID" '%s:%lld'"
+                 WSREP_SST_OPT_GTID" '%s:%lld' "
                  "%s",
                  method, addr, mysqld_unix_port, mysql_real_data_home,
                  wsrep_defaults_file, wsrep_defaults_group_suffix,
+                 MYSQL_SERVER_VERSION MYSQL_SERVER_SUFFIX_DEF,
                  binlog_opt, binlog_opt_val,
                  uuid, (long long) seqno,
-                 bypass ? " "WSREP_SST_OPT_BYPASS : "");
+                 bypass ? " " WSREP_SST_OPT_BYPASS : "");
   my_free(binlog_opt_val);
 
   if (ret < 0 || ret >= cmd_len)
@@ -1265,7 +1284,6 @@ wsrep_cb_status_t wsrep_sst_donate_cb (void* app_ctx, void* recv_ctx,
 {
   /* This will be reset when sync callback is called.
    * Should we set wsrep_ready to FALSE here too? */
-//  wsrep_notify_status(WSREP_MEMBER_DONOR);
   local_status.set(WSREP_MEMBER_DONOR);
 
   const char* method = (char*)msg;
